@@ -145,7 +145,7 @@ double cpp_std_error(NumericVector x)
   
 }
   
-// @export  
+ 
 // [[Rcpp::export]] 
 double cpp_geom_mean(NumericVector x)
 {
@@ -154,6 +154,21 @@ double cpp_geom_mean(NumericVector x)
   
 } 
 
+
+
+// [[Rcpp::export]] 
+double cpp_harmonic_mean(NumericVector x)
+{
+        double sum_val = 0.0;
+        
+        for (int i = 0; i < x.size(); i++){
+                sum_val += 1.0/x[i];
+        }
+        return x.size() / sum_val;
+} 
+
+
+
 // @export
 // [[Rcpp::export]]
   NumericMatrix cpp_omitMatrix(NumericMatrix ExpressionSet, NumericVector AgeVector){
